@@ -2,7 +2,9 @@
 
 #[cfg(feature = "compression")]
 mod compress;
-mod cookie;
+#[cfg(feature = "cookie")]
+#[cfg_attr(docsrs, doc(cfg(feature = "cookie")))]
+pub mod cookie;
 mod data;
 mod form;
 mod json;
@@ -54,7 +56,6 @@ pub use template::{HtmlTemplate, Template};
 #[cfg_attr(docsrs, doc(cfg(feature = "typed-headers")))]
 pub use typed_header::TypedHeader;
 
-pub use self::cookie::{Cookie, CookieJar};
 #[cfg(feature = "tempfile")]
 pub use self::tempfile::TempFile;
 use crate::{
